[![status](http://joss.theoj.org/papers/74487c5a6820fb2fe2898960ad6d2ea0/status.svg)](http://joss.theoj.org/papers/74487c5a6820fb2fe2898960ad6d2ea0)

Welcome to the README for the Lithology component submodule.

This submodule was published as a [Journal of Open Source
Software](http://joss.theoj.org) publication. Click the badge above to be
directed to the paper.

There is a [jupyter notebook in the Landlab Tutorials
repository](https://mybinder.org/v2/gh/landlab/landlab/release?filepath=notebooks/tutorials/lithology/lithology_and_litholayers.ipynb)
that describes the use of this submodule.

If you have any questions, comments, issues, or bugs related to this submodule,
please [open an Issue](https://github.com/landlab/landlab/issues) so we can
respond.
